@@ -21,11 +21,7 @@ use crate::types::{
     TextEntityError,
 };
 use serde::Deserialize;
-use std::{
-    convert::TryFrom,
-    error::{Error as StdError, Error},
-    fmt,
-};
+use std::{convert::TryFrom, error::Error as StdError, fmt};
 
 /// Contains message data
 #[derive(Clone, Debug, Deserialize)]
@@ -266,7 +262,7 @@ pub enum MessageDataError {
 }
 
 impl StdError for MessageDataError {
-    fn source(&self) -> Option<&(dyn Error + 'static)> {
+    fn source(&self) -> Option<&(dyn StdError + 'static)> {
         match self {
             MessageDataError::TextEntity(err) => Some(err),
         }
